@@ -55,6 +55,8 @@ new KinesisStreamsToKinesisFirehoseToS3(scope: Construct, id: string, props: Kin
 |kinesisFirehoseProps?|[`kinesisfirehose.CfnDeliveryStreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesisfirehose.CfnDeliveryStreamProps.html)|`any`|Optional user provided props to override the default props for Kinesis Firehose Delivery Stream.|
 |kinesisStreamProps?|[`kinesis.StreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.StreamProps.html)|Optional user-provided props to override the default props for the Kinesis stream.|
 |logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|Optional user provided props to override the default props for for the CloudWatchLogs LogGroup.|
+|loggingBucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|Optional user provided props to override the default props for the S3 Logging Bucket.|
+|logS3AccessLogs?| boolean|Whether to turn on Access Logging for the S3 bucket. Creates an S3 bucket with associated storage costs for the logs. Enabling Access Logging is a best practice. default - true|
 
 ## Pattern Properties
 
@@ -68,6 +70,7 @@ new KinesisStreamsToKinesisFirehoseToS3(scope: Construct, id: string, props: Kin
 |kinesisStreamRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of the iam.Role created by the construct for Kinesis stream|
 |s3Bucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct|
 |s3LoggingBucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary bucket|
+|s3BucketInterface|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Returns an instance of s3.IBucket created by the construct|
 
 ## Default settings
 
@@ -141,7 +144,9 @@ class KinesisStreamsToKinesisFirehoseToS3(
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -153,7 +158,9 @@ class KinesisStreamsToKinesisFirehoseToS3(
         :param existing_stream_obj: Optional existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error. Default: - None
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
+        :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         :param log_group_props: Optional user provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
+        :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
 
         :access: public
         :since: 1.68.0
@@ -167,7 +174,9 @@ class KinesisStreamsToKinesisFirehoseToS3(
             existing_stream_obj=existing_stream_obj,
             kinesis_firehose_props=kinesis_firehose_props,
             kinesis_stream_props=kinesis_stream_props,
+            logging_bucket_props=logging_bucket_props,
             log_group_props=log_group_props,
+            log_s3_access_logs=log_s3_access_logs,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -197,6 +206,11 @@ class KinesisStreamsToKinesisFirehoseToS3(
     def kinesis_stream_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "kinesisStreamRole"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="s3BucketInterface")
+    def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
+        return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
@@ -226,7 +240,9 @@ class KinesisStreamsToKinesisFirehoseToS3(
         "existing_stream_obj": "existingStreamObj",
         "kinesis_firehose_props": "kinesisFirehoseProps",
         "kinesis_stream_props": "kinesisStreamProps",
+        "logging_bucket_props": "loggingBucketProps",
         "log_group_props": "logGroupProps",
+        "log_s3_access_logs": "logS3AccessLogs",
     },
 )
 class KinesisStreamsToKinesisFirehoseToS3Props:
@@ -240,7 +256,9 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_s3_access_logs: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''The properties for the KinesisStreamsToKinesisFirehoseToS3 class.
 
@@ -251,12 +269,16 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :param existing_stream_obj: Optional existing instance of Kinesis Stream, providing both this and ``kinesisStreamProps`` will cause an error. Default: - None
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
+        :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         :param log_group_props: Optional user provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
+        :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
         '''
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(kinesis_stream_props, dict):
             kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
+        if isinstance(logging_bucket_props, dict):
+            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         self._values: typing.Dict[str, typing.Any] = {}
@@ -274,8 +296,12 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
             self._values["kinesis_firehose_props"] = kinesis_firehose_props
         if kinesis_stream_props is not None:
             self._values["kinesis_stream_props"] = kinesis_stream_props
+        if logging_bucket_props is not None:
+            self._values["logging_bucket_props"] = logging_bucket_props
         if log_group_props is not None:
             self._values["log_group_props"] = log_group_props
+        if log_s3_access_logs is not None:
+            self._values["log_s3_access_logs"] = log_s3_access_logs
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
@@ -342,6 +368,15 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         result = self._values.get("kinesis_stream_props")
         return typing.cast(typing.Optional[aws_cdk.aws_kinesis.StreamProps], result)
 
+    @builtins.property
+    def logging_bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+        '''Optional user provided props to override the default props for the S3 Logging Bucket.
+
+        :default: - Default props are used
+        '''
+        result = self._values.get("logging_bucket_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
         '''Optional user provided props to override the default props for the CloudWatchLogs LogGroup.
@@ -351,6 +386,17 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         result = self._values.get("log_group_props")
         return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
+    @builtins.property
+    def log_s3_access_logs(self) -> typing.Optional[builtins.bool]:
+        '''Whether to turn on Access Logs for the S3 bucket with the associated storage costs.
+
+        Enabling Access Logging is a best practice.
+
+        :default: - true
+        '''
+        result = self._values.get("log_s3_access_logs")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
